@@ -518,6 +518,9 @@ class ChunkedArray(awkward.array.base.AwkwardArray):
     def __array_ufunc__(self, ufunc, method, *inputs, **kwargs):
         import awkward.array.objects
 
+        if "out" in kwargs:
+            raise NotImplementedError("in-place operations not supported")
+
         if method != "__call__":
             return NotImplemented
 
